# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [0.1.0] - 2022-12-02
### Added
- An extension to [tanjun.annotations][] which allows for parsing slash command
  descriptions (including for options) from the command callback's docstring +
  using the callback's name as the command's name.

[Unreleased]: https://github.com/FasterSpeeding/tanchan/compare/v0.1.0...HEAD
[0.1.0]: https://github.com/FasterSpeeding/tanchan/compare/c4525eb9271445d3c74dbe747952faf2c830716b...v0.1.0
